summaryrefslogtreecommitdiffstats
path: root/chrome/browser/extensions/sandboxed_extension_unpacker.h
diff options
context:
space:
mode:
authoraa@chromium.org <aa@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-03-19 20:45:46 +0000
committeraa@chromium.org <aa@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-03-19 20:45:46 +0000
commit867a73e1e2aad10f60952235da84f5d98cff9aa6 (patch)
tree5e977ff9c87a2cd3de2d7f50b057adbdad4c70bf /chrome/browser/extensions/sandboxed_extension_unpacker.h
parent35de4be0f924ef6279a6a25fe840522524fa177b (diff)
downloadchromium_src-867a73e1e2aad10f60952235da84f5d98cff9aa6.zip
chromium_src-867a73e1e2aad10f60952235da84f5d98cff9aa6.tar.gz
chromium_src-867a73e1e2aad10f60952235da84f5d98cff9aa6.tar.bz2
Resubmit 1025006: Refactor app-related manifest properties
so that they don't include the name 'app'. TBR=erikkay@chromium.org git-svn-id: svn://svn.chromium.org/chrome/trunk/src@42146 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/extensions/sandboxed_extension_unpacker.h')
-rw-r--r--chrome/browser/extensions/sandboxed_extension_unpacker.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/chrome/browser/extensions/sandboxed_extension_unpacker.h b/chrome/browser/extensions/sandboxed_extension_unpacker.h
index 25d77b6..a3b190c 100644
--- a/chrome/browser/extensions/sandboxed_extension_unpacker.h
+++ b/chrome/browser/extensions/sandboxed_extension_unpacker.h
@@ -96,9 +96,9 @@ class SandboxedExtensionUnpacker : public UtilityProcessHost::Client {
ResourceDispatcherHost* rdh,
SandboxedExtensionUnpackerClient* cilent);
- const GURL& app_origin_override() const { return app_origin_override_; }
- void set_app_origin_override(const GURL& val) {
- app_origin_override_ = val;
+ const GURL& web_origin() const { return web_origin_; }
+ void set_web_origin(const GURL& val) {
+ web_origin_ = val;
}
// Start unpacking the extension. The client is called with the results.
@@ -169,10 +169,10 @@ class SandboxedExtensionUnpacker : public UtilityProcessHost::Client {
// The public key that was extracted from the CRX header.
std::string public_key_;
- // If the unpacked extension is an app, its origin will be forced to this
- // value. This is used when an app is self-hosted. The only valid origin
- // is the origin it is served from.
- GURL app_origin_override_;
+ // If the unpacked extension uses web content, its origin will be set to this
+ // value. This is used when an app is self-hosted. The only valid origin is
+ // the origin it is served from.
+ GURL web_origin_;
};
#endif // CHROME_BROWSER_EXTENSIONS_SANDBOXED_EXTENSION_UNPACKER_H_